@@ -662,17 +662,17 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
             xmin = rng.lower
             xmax = rng.upper
             idx = n.argwhere((x >= xmin) & (x < xmax)).ravel()
-            if bkg:
+            if bkg is not None:
                 # self._background_map[rng.id] = bkg
                 rng_bkg = bkg.eval(x[idx])
                 rng_signal = y[idx] - rng_bkg
                 sig_y[idx] = rng_signal
                 bkg_y[idx] = rng_bkg
             else:
+                sig_y[idx] = y[idx]
                 if self.show_warnings:
                     warn(f"No background could be matched to {rng.ion.hill_formula} from {rng.lower}-{rng.upper} Da."
                          f" This range will not be background corrected.")
-                    sig_y[idx] = y[idx]
 
         self.__local_bkg_hist = (x, bkg_y)
         self.__corrected_hist = (x, sig_y)
