@@ -118,9 +118,6 @@ def str2composition(formula: str) -> Dict[Element, int]:
 
     # Convert the matches to a dict
     for elem, count in matches:
-        # if elem not in _syms:
-        #     raise ValueError(f"The elemental symbol {elem} does not exist")
-
         if elem in _syms:
             element = el.symbol(elem)
         else:
@@ -382,6 +379,8 @@ class IsotopeSeries:
         """
         if isinstance(args[0], Ion) and len(args) == 1:
             ion = args[0]
+        elif isinstance(args[0], str) and len(args) == 1:
+            ion = Ion(args[0], 1)
         elif len(args) == 2:
             if isinstance(args[0], str) and isinstance(args[1], int):
                 ion = Ion(args[0], args[1])
