@@ -415,13 +415,13 @@ class RangeCollection:
         """
         return tuple(set([i.ion for i in self.ranges]))
 
-    def elements(self) -> tuple:
+    def elements(self) -> Tuple[Element]:
         """
         Get a tuple of all elements
         """
         allelems = []
         for rng in self:
-            elems = [i.symbol for i in rng.ion.elements]
+            elems = [i for i in rng.ion.elements]
             allelems += elems
 
         return tuple(set(allelems))
