@@ -800,13 +800,15 @@ class RoiRectPrism(RoiSubsetType):
                            (zc-dz, zc+dz)
         xyz = self.xyz
 
+        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1])).ravel()
+        idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
+        idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
+
         # First filter out everything outside of the bounding box
-        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-                         (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-                         (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
+        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
+        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
+        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
 
-        if idx.size == 0:
-            raise ValueError("Roi contains no data points")
         self._mask = idx
 
 
@@ -840,17 +842,18 @@ class RoiSphere(RoiSubsetType):
         xyz = self.xyz
 
         # First filter out everything outside of the bounding box
-        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-                         (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-                         (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
+        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1])).ravel()
+        idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
+        idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
+
+        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
+        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
+        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
 
         # Then filter out everything not within the sphere radius
         r = la.norm((xyz[idx]-center), axis=1)
         idx = idx[n.argwhere(r < radius).ravel()]
 
-        if idx.size == 0:
-            raise ValueError("Roi contains no data points")
-
         self._mask = idx
 
 
@@ -900,17 +903,18 @@ class RoiCylinder(RoiSubsetType):
         xyz = self.xyz
 
         # First filter out everything outside of the bounding box of the cylinder
-        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-                         (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-                         (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
+        idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1])).ravel()
+        idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
+        idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
+
+        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
+        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
+        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
 
         # Then filter out everything not within the cylinder radius
         r = la.norm((xyz[idx]-center)[:, non_axial_idx], axis=1)
         idx = idx[n.argwhere(r < radius).ravel()]
 
-        if idx.size == 0:
-            raise ValueError("Roi contains no data points")
-
         self._mask = idx
 
 
