@@ -23,6 +23,7 @@ along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 from apav import Roi, RangeCollection
 from apav.utils.helpers import data_path
 from apav.utils import validate
+import apav as ap
 
 import numpy as n
 from pytest import raises
@@ -141,6 +142,22 @@ class TestRoi:
         with raises(validate.NoTOFError):
             posrun.tof_histogram()
 
+    def test_load_pos(self):
+        fpos = data_path("Si.pos")
+        ap.load_pos(fpos)
+
+    def test_load_epos(self):
+        fepos = data_path("Si.epos")
+        ap.load_epos(fepos)
+
+    # def test_load_ato(self):
+    #     fato = data_path("Si.ato")
+    #     ap.load_ato(fato)
+
+    def test_load_apt(self):
+        fapt = data_path("Si.apt")
+        ap.load_apt(fapt)
+
     def test_from_epos(self):
         fepos = data_path("Si.epos")
         eposrun = Roi.from_epos(fepos)
